@@ -8,15 +8,19 @@
 """Provides Qt3DInput classes and functions."""
 
 # Local imports
-from . import PYQT5, PYSIDE2, PythonQtError
+from . import PYQT5, PYSIDE2, PythonQtError, PYSIDE_VERSION
+from .py3compat import PY2
 
 if PYQT5:
     from PyQt5.Qt3DInput import *
 elif PYSIDE2:
-    # https://bugreports.qt.io/projects/PYSIDE/issues/PYSIDE-1026
-    import PySide2.Qt3DInput as __temp
-    import inspect
-    for __name in inspect.getmembers(__temp.Qt3DInput):
-        globals()[__name[0]] = __name[1]
+    if not PY2 or (PY2 and PYSIDE_VERSION < '5.12.4'):
+        # https://bugreports.qt.io/projects/PYSIDE/issues/PYSIDE-1026
+        import PySide2.Qt3DInput as __temp
+        import inspect
+        for __name in inspect.getmembers(__temp.Qt3DInput):
+            globals()[__name[0]] = __name[1]
+    else:
+        raise PythonQtError('A bug in Shiboken prevents this')
 else:
     raise PythonQtError('No Qt bindings could be found')
